Texture2D

Struct Texture2D 

pub struct Texture2D {
    pub name: String,
    pub data: TextureData,
    pub width: u32,
    pub height: u32,
    pub min_filter: Interpolation,
    pub mag_filter: Interpolation,
    pub mipmap: Option<Mipmap>,
    pub wrap_s: Wrapping,
    pub wrap_t: Wrapping,
}
A CPU-side version of a 2D texture.

Fields

name: String

Name of this texture.

data: TextureData

The pixel data for the image

width: u32

The width of the image

height: u32

The height of the image

min_filter: Interpolation

The way the pixel data is interpolated when the texture is far away

mag_filter: Interpolation

The way the pixel data is interpolated when the texture is close

mipmap: Option<Mipmap>

Specifies the Mipmap settings for this texture. If this is None, no mipmaps are created.

wrap_s: Wrapping

Determines how the texture is sampled outside the [0..1] s coordinate range (the first value of the uv coordinates).

wrap_t: Wrapping

Determines how the texture is sampled outside the [0..1] t coordinate range (the second value of the uv coordinates).