pub enum Wrapping {
Repeat,
MirroredRepeat,
ClampToEdge,
}Expand description
Possible wrapping modes for a texture which determines how the texture is applied outside of the [0..1] uv coordinate range.
Variants