pub struct Mipmap {
pub filter: Interpolation,
pub max_levels: u32,
pub max_ratio: u32,
}Expand description
Mipmap settings for a texture.
Fields
filter: InterpolationSpecifies what type of interpolation to use between the two closest mipmaps.
max_levels: u32Specifies the maximum number of mipmap levels that should be created for the texture. If this is 1, no mip maps will be created.
max_ratio: u32Specifies the maximum ratio of anisotropy to be used when creating mipmaps for the texture. If this is 1, only isotropic mipmaps will be created.