pub struct Texture3D {
pub name: String,
pub data: TextureData,
pub width: u32,
pub height: u32,
pub depth: u32,
pub min_filter: Interpolation,
pub mag_filter: Interpolation,
pub mipmap: Option<Mipmap>,
pub wrap_s: Wrapping,
pub wrap_t: Wrapping,
pub wrap_r: Wrapping,
}Expand description
A CPU-side version of a 3D texture.
Fields
name: StringName of this texture.
data: TextureDataThe pixel data for the image
width: u32The width of the image
height: u32The height of the image
depth: u32The depth of the image
min_filter: InterpolationThe way the pixel data is interpolated when the texture is far away
mag_filter: InterpolationThe way the pixel data is interpolated when the texture is close
mipmap: Option<Mipmap>Specifies the Mipmap settings for this texture. If this is None, no mipmaps are created.
wrap_s: WrappingDetermines how the texture is sampled outside the [0..1] s coordinate range (the first value of the uvw coordinates).
wrap_t: WrappingDetermines how the texture is sampled outside the [0..1] t coordinate range (the second value of the uvw coordinates).
wrap_r: WrappingDetermines how the texture is sampled outside the [0..1] r coordinate range (the third value of the uvw coordinates).